/*
 * vim:tw=180:ts=8:sw=8
 *
 * Program name:	pure-config
 *
 * Description:		Parser-converter for main configuration pure-ftpd file
 * 			written in C, on the top of libcfg+ - see:
 * 			http://platon.sk/projects/libcfg+/.
 *
 * Copyright:		Tomasz Wittner, 2004 under terms of GNU GPL v.2 license.
 *
 */

#include "config.h"
#ifdef HAVE_CFG__H
#include <cfg+.h>
#endif

#define OPTQNT	65
#define CFGFILE	0
#define DEBUG	1
#define HELP	2
#define LONGOPT 3
#define SEMICOL_S 51
#define SEMICOL_E SEMICOL_S + 7
#define I __LINE__ - 34


char *opt[OPTQNT];

struct cfg_option options[] = {

/*	cmdline_long,		cmdline_short,	cfgfile_name,			cfg_option_type,		value			val		*/
	{	"file",		'f',		NULL,				CFG_STR,			(void*) &opt[I],	0 },
	{	"debug",	'd',		NULL,				CFG_BOOL,			(void*) &opt[I],	0 },
	{	"help",		'h', 		NULL,				CFG_BOOL,			(void*) &opt[I],	0 },
	{	"long",		'l',		NULL,				CFG_BOOL,			(void*) &opt[I],	0 },
	{	"verbose",	'v',		NULL,				CFG_BOOL,			(void*) &opt[I],	0 }, /* not implemented */
	{	NULL,		'\0', /* '4' */	"IPV4Only",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* '6' */	"IPV6Only",        		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'A' */	"ChrootEveryone",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'b' */	"BrokenClientsCompatibility",	CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'B' */	"Daemonize",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'd' */	"VerboseLog",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'D' */	"DisplayDotFiles",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'e' */	"AnonymousOnly",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'E' */	"NoAnonymous",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'H' */	"DontResolve",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'M' */	"AnonymousCanCreateDirs",	CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'N' */	"NATmode",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'o' */	"CallUploadScript",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 's' */	"AntiWarez",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'w' */	"AllowUserFXP",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'W' */	"AllowAnonymousFXP",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'x' */	"ProhibitDotFilesWrite",	CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'X' */	"ProhibitDotFilesRead",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'z' */	"AllowDotFiles",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'r' */	"AutoRename",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'i' */	"AnonymousCantUpload",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* '1' */	"LogPID",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'R' */	"NoChmod",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'K' */	"KeepAllFiles",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'j' */	"CreateHomeDir",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'G' */	"NoRename",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'Z' */	"CustomerProof",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* '0' */	"NoTruncate",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'f' */	"SyslogFacility",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'F' */	"FortunesFile",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'P' */	"ForcePassiveIP",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'S' */	"Bind",				CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 't' */	"AnonymousBandwidth",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'T' */	"UserBandwidth",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'V' */	"TrustedIP",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'O' */	"AltLog",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'g' */	"PIDFile",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* '7' */	"SSLCertFile",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'I' */	"MaxIdleTime",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'k' */	"MaxDiskUsage",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'a' */	"TrustedGID",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'c' */	"MaxClientsNumber",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'C' */	"MaxClientsPerIP",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'm' */	"MaxLoad",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'u' */	"MinUID",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'Y' */	"TLS",				CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'L' */	"LimitRecursion",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'p' */	"PassivePortRange",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'q' */	"AnonymousRatio",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'Q' */	"UserRatio",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'U' */	"Umask",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'n' */	"Quota",			CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* 'y' */	"PerUserLimits",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* lldap: */	"LDAPConfigFile",	CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* lmysql: */	"MySQLConfigFile",	CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* lpgsql: */	"PGSQLConfigFile",	CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* lpuredb: */	"PureDB",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* lextauth: */	"ExtAuth",		CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* lpam */	"PAMAuthentication",	CFG_STR,			(void*) &opt[I],	0 },
	{	NULL,		'\0', /* lunix */	"UnixAuthentication",	CFG_STR,			(void*) &opt[I],	0 },
	CFG_END_OF_LIST
};

char *output[OPTQNT][2] = {

	{	"",	""				},
	{	"",	""				},
	{	"",	""				},
	{	"",	""				},
	{	"",	""				},
	{	"-4",	"--ipv4only"			},
	{	"-6",	"--ipv6only"			},
	{	"-A",	"--chrooteveryone"		},
	{	"-b",	"--brokenclientscompatibility"	},
	{	"-B",	"--daemonize"			},
	{	"-d",	"--verboselog"			},
	{	"-D",	"--displaydotfiles"		},
	{	"-e",	"--anonymousonly"		},
	{	"-E",	"--noanonymous"			},
	{	"-H",	"--dontresolve"			},
	{	"-M",	"--anonymouscancreatedirs"	},
	{	"-N",	"--natmode"			},
	{	"-o",	"--calluploadscript"		},
	{	"-s",	"--antiwarez"			},
	{	"-w",	"--allowuserfxp"		},
	{	"-W",	"--allowanonymousfxp"		},
	{	"-x",	"--prohibitdotfileswrite"	},
	{	"-X",	"--prohibitdotfilesread"	},
	{	"-z",	"--allowdotfiles"		},
	{	"-r",	"--autorename"			},
	{	"-i",	"--anonymouscantupload"		},
	{	"-1",	"--logpid="			},
	{	"-R",	"--nochmod"			},
	{	"-K",	"--keepallfiles"		},
	{	"-j",	"--createhomedir"		},
	{	"-G",	"--norename"			},
	{	"-Z",	"--customerproof"		},
	{	"-0",	"--notruncate"			},
	{	"-f",	"--syslogfacility="		},
	{	"-F",	"--fortunesfile="		},
	{	"-P",	"--forcepassiveip="		},
	{	"-S",	"--bind="			},
	{	"-t",	"--anonymousbandwidth="		},
	{	"-T",	"--userbandwidth="		},
	{	"-V",	"--trustedip="			},
	{	"-O",	"--altlog="			},
	{	"-g",	"--pidfile="			},
	{	"-7",	"--sslcertfile="		},
	{	"-I",	"--maxidletime="		},
	{	"-k",	"--maxdiskusage="		},
	{	"-a",	"--trustedgid="			},
	{	"-c",	"--maxclientsnumber="		},
	{	"-C",	"--maxclientsperip="		},
	{	"-m",	"--maxload="			},
	{	"-u",	"--minuid="			},
	{	"-Y",	"--tls="			},
	{	"-L",	"--limitrecursion="		},
	{	"-p",	"--passiveportrange="		},
	{	"-q",	"--anonymousratio="		},
	{	"-Q",	"--userratio="			},
	{	"-U",	"--umask="			},
	{	"-n",	"--quota="			},
	{	"-y",	"--peruserlimits="		},
	{	"-lldap:",	"--login=ldap:"		},
	{	"-lmysql:",	"--login=mysql:"	},
	{	"-lpgsql:",	"--login=pgsql:"	},
	{	"-lpuredb:",	"--login=puredb:"	},
	{	"-lextauth:",	"--login=extauth:"	},
	{	"-lpam",	"--login=pam"		},
	{	"-lunix",	"--login=unix"		}

};

